@@ -57,6 +57,8 @@ class Citation:
         processed_tokens: Dictionary of tokens after they have been
             modified via the template's processes.
         URL: The URL where a user can read this citation online
+        authority: The Authority that this citation is a reference to.
+            This attribute is not set until list_authorities() is run.
     """
     def __init__(self, match: re.Match, template):
         """
@@ -194,7 +196,7 @@ class Authority:
             generic citation to this authority.
         name: The text of base_citation
     """
-    def __init__(self, first_cite, allowed_differences: list=[]):
+    def __init__(self, first_cite: Citation, allowed_differences: list=[]):
         """
         Define an authority by providing a single long-form citation,
         and the list of tokens which, if present in the citation, should
@@ -229,6 +231,7 @@ class Authority:
         # Next, derive a base citation to represent this authority.
         # If the first_citation to this authority isn't a longform, use
         # whatever longform it's a child of.
+        self.base_citation: Citation = None
         try:
             self.base_citation = self._derive_base_citation(long_cite)
         except TypeError:
@@ -240,7 +243,7 @@ class Authority:
         first_cite.authority = self
     
     def include(self, citation):
-        """Adds the citation to this template's list of citations. Also,
+        """Adds the citation to this authority's list of citations. Also,
         adds the `authority` tag to the citation, referring back to this
         authority."""
         self.citations.append(citation)
@@ -413,13 +416,16 @@ class Citator:
         for template in self.templates:
             citations += template.get_citations(text)
         shortform_cites = []
+        
         # Then, add shortforms
         for citation in citations:
             shortform_cites += citation._get_shortform_citations(text)
         citations += shortform_cites
         citations = _sort_and_remove_overlaps(citations)
+        
         if not id_forms: # no need to proceed
             return citations
+        
         # determine where to break chains of id. citations
         for citation in citations: # break at full or short citations
             id_break_indices.append(citation.span[0])
@@ -428,6 +434,7 @@ class Citator:
             for match in matches:
                 id_break_indices.append(match.span()[0])
         id_break_indices = sorted(set(id_break_indices))
+        
         # loop through all citations to find their id citations
         id_citations = []
         for citation in citations:
@@ -534,7 +541,7 @@ class Template:
         shortForms: list[str]=[],
         defaults: dict={},
         operations: list[dict]=[],
-        parent_citation=None,
+        parent_citation: Citation=None,
         _is_id=False
     ):
         """
@@ -878,19 +885,29 @@ def insert_links(
     """
     offset = 0
     for citation in citations:
+        # by default, skip citations without URLs
         if not citation.URL and not url_optional:
             continue
+        
         if citation.template.is_id:
-            if citation.template._compiled_re().groupindex:
-                if not link_detailed_ids:
+            # check whether the matched citation is from a template that
+            # has any named capture groups. If it doesn't, it's a
+            # "plain id." and should normally be skipped
+            if not '(?P<' in citation.template._compiled_re().pattern:
+                if not link_plain_ids:
                     continue
-            elif not link_plain_ids:
+            elif not link_detailed_ids:
                 continue
+        
         link = citation.get_link(attrs=attrs)
+        
+        # insert each link into the proper place by offsetting later
+        # citations by however many extra characters are added by each
         cite_start = citation.span[0] + offset
         cite_end = citation.span[1] + offset
         text = ''.join([text[:cite_start], link, text[cite_end:]])
         offset += len(link) - len(citation.text)
+    
     return text
 
 
@@ -941,7 +958,7 @@ def list_authorities(
     
     Arguments:
         citations: The list of citations to combine
-        unimportant_tokens: A list of tokens whose values may 
+        irrelevant_tokens: A list of tokens whose values may 
             differ among citations to the same authority.
     Returns:
         A list of authority objects, sorted by the number of citations
